@@ -2,6 +2,8 @@ import time
 import random
 import uuid
 import ctypes
+import wave
+
 import win32clipboard
 import win32con
 import win32gui
@@ -348,4 +350,18 @@ if __name__ == '__main__':
     # change_language_layout(-0x1fddf7fc)
     # enable_network_adapter('本地连接')
     # disable_network_adapter('本地连接')
-    play_wave('../警报声.wav')
+    # import threading
+    # threading.Thread(target=play_wave, args=('../警报声.wav',)).start()
+    # play_wave('../警报声.wav')
+    # play_wave('../警报声.wav')
+    # with open('../警报声.wav', 'rb') as f:
+    #     data = f.read()[::-1]
+    # with open('test.wav', 'wb') as f:
+    #     f.write(data)
+    # play_wave('test.wav')
+    # wav = wave.open('../警报声.wav')
+    # wav_obj = sa.WaveObject.from_wave_read(wav)
+    # wav_obj.play().wait_done()
+    # wav_obj.play().wait_done()
+    # wav_obj.play().wait_done()
+    pass
