@@ -505,6 +505,13 @@ class Core(metaclass=SingletonType):
             raise TypeError('param window must be <class Notification>')
         self.__window = window
 
+    def get_configs(self):
+        """
+        获取配置字典
+        :return:
+        """
+        return self.__configs
+
     def add_config(self, config):
         """
         添加配置实例
