@@ -17,9 +17,9 @@ class Macro(metaclass=SingletonType):
         :param max_workers: 线程池最大线程数
         :param start_message: 启动时的显示语
         """
-        self.__pool = ThreadPoolExecutor(max_workers=max_workers)
+        self.pool = ThreadPoolExecutor(max_workers=max_workers)
         self.__message = start_message
-        self.__core = Core(self.__pool, switch_key=switch_key)
+        self.__core = Core(self.pool, switch_key=switch_key)
 
     def __sub_thread(self):
         """
@@ -66,8 +66,8 @@ class Macro(metaclass=SingletonType):
         """
         window = Notification(fg=fg, bg=bg)
         self.__core.add_window(window)
-        self.__pool.submit(self.__start_gui, window)
-        self.__pool.submit(self.__sub_thread)
+        self.pool.submit(self.__start_gui, window)
+        self.pool.submit(self.__sub_thread)
         window.run()
 
     def get_flag_run(self):
